==> rc-ui-lib-0.1.29.tgz: package/es/switch/Switch.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useMemo } from 'react';
import classnames from 'classnames';
import useMergedState from '../hooks/use-merged-state';
import Loading from '../loading';
import { createNamespace, addUnit } from '../utils';

var _createNamespace = createNamespace('switch'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var Swtich = function Swtich(props) {
  var loading = props.loading,
      disabled = props.disabled,
      size = props.size,
      activeColor = props.activeColor,
      inactiveColor = props.inactiveColor;

  var _useMergedState = useMergedState({
    value: props.checked,
    defaultValue: props.defaultChecked
  }),
      _useMergedState2 = _slicedToArray(_useMergedState, 2),
      checked = _useMergedState2[0],
      setChecked = _useMergedState2[1];

  var isChecked = useMemo(function () {
    return checked === props.activeValue;
  }, [checked, props.activeValue]);

  var style = _objectSpread({
    fontSize: addUnit(size),
    backgroundColor: isChecked ? activeColor : inactiveColor
  }, props.style);

  var onClick = function onClick(e) {
    if (!props.disabled) {
      var _props$onClick;

      (_props$onClick = props.onClick) === null || _props$onClick === void 0 ? void 0 : _props$onClick.call(props, e);
    }

    if (!props.disabled && !props.loading) {
      var _props$onChange;

      var newValue = isChecked ? props.inactiveValue : props.activeValue;
      setChecked(newValue);
      (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, newValue);
    }
  };

  var renderLoading = function renderLoading() {
    if (props.loading) {
      var color = isChecked ? props.activeColor : props.inactiveColor;
      return /*#__PURE__*/React.createElement(Loading, {
        className: classnames(bem('loading')),
        color: color
      });
    }

    return null;
  };

  return /*#__PURE__*/React.createElement("div", {
    role: "switch",
    tabIndex: 0,
    className: classnames(props.className, bem({
      on: isChecked,
      loading: loading,
      disabled: disabled
    })),
    style: style,
    "aria-checked": isChecked,
    onClick: onClick
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('node'))
  }, renderLoading()));
};

Swtich.defaultProps = {
  activeValue: true,
  inactiveValue: false
};
export default Swtich;

==> rc-ui-lib-0.1.41.tgz: package/es/switch/Switch.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import useMergedState from '../hooks/use-merged-state';
import Loading from '../loading';
import { addUnit } from '../utils';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Swtich = function Swtich(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('switch', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var loading = props.loading,
      disabled = props.disabled,
      size = props.size,
      activeColor = props.activeColor,
      inactiveColor = props.inactiveColor;

  var _useMergedState = useMergedState({
    value: props.checked,
    defaultValue: props.defaultChecked
  }),
      _useMergedState2 = _slicedToArray(_useMergedState, 2),
      checked = _useMergedState2[0],
      setChecked = _useMergedState2[1];

  var isChecked = useMemo(function () {
    return checked === props.activeValue;
  }, [checked, props.activeValue]);

  var style = _objectSpread({
    fontSize: addUnit(size),
    backgroundColor: isChecked ? activeColor : inactiveColor
  }, props.style);

  var onClick = function onClick(e) {
    if (!props.disabled) {
      var _props$onClick;

      (_props$onClick = props.onClick) === null || _props$onClick === void 0 ? void 0 : _props$onClick.call(props, e);
    }

    if (!props.disabled && !props.loading) {
      var _props$onChange;

      var newValue = isChecked ? props.inactiveValue : props.activeValue;
      setChecked(newValue);
      (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, newValue);
    }
  };

  var renderLoading = function renderLoading() {
    if (props.loading) {
      var color = isChecked ? props.activeColor : props.inactiveColor;
      return /*#__PURE__*/React.createElement(Loading, {
        className: classnames(bem('loading')),
        color: color
      });
    }

    return null;
  };

  return /*#__PURE__*/React.createElement("div", {
    role: "switch",
    tabIndex: 0,
    className: classnames(props.className, bem({
      on: isChecked,
      loading: loading,
      disabled: disabled
    })),
    style: style,
    "aria-checked": isChecked,
    onClick: onClick
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('node'))
  }, renderLoading()));
};

Swtich.defaultProps = {
  activeValue: true,
  inactiveValue: false
};
export default Swtich;
